import React, { useCallback, useEffect, useRef, useState } from 'react';
import useResize from '@/utils/hooks/useResize';

export function useFullScreen() {
  const [style, setStyle] = useState({});
  const [isFullScreen, setIsFullScreen] = useState(false);
  const fullScreenRef = useRef();
  fullScreenRef.current = isFullScreen;

  const calcStyle = useCallback(() => {
    const container = document.querySelector('main.ant-layout-content');
    const header = container.querySelector('.ant-pro-page-container-warp');
    const height = container.offsetHeight - header.offsetHeight;

    setStyle({
      width: '100%',
      height: `${height}px`,
    });
  }, []);

  const onFullScreen = useCallback((e) => {
    document.documentElement.requestFullscreen();
  }, []);

  useResize((w, h) => {
    if (fullScreenRef.current) {
      calcStyle();
    } else {
      setStyle({
        width: `${w}px`,
        height: `${h}px`,
      });
    }

    setIsFullScreen(!fullScreenRef.current);
  });

  useEffect(() => {
    calcStyle();
  }, []);

  return { style, isFullScreen, onFullScreen };
}
