import { history, Link } from 'umi';
import { useRef } from 'react';
import { Button, Modal, message, Popconfirm, Tooltip } from 'antd';
import { PlusOutlined, QuestionCircleOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import ProTable, { TableDropdown } from '@ant-design/pro-table';


export default (props) => {
  const dataSource = [
    {
      id: 9,
      key: '1',
      name: '胡彦斌',
      age: 32,
      status: 0,
      zz: '西湖区湖底公园1号',
    },

  ];


  // 测试内容👆-------------------------

  const actionRef = useRef();
  const gotoDetail = (id) => {
    history.push(`Administrator/AdminEdit`)
  }


  const handleDelete = (e) => {
    deleteNote(e.noteId).then(res => {
      message.success('删除成功');
      actionRef.current.reload();
    })
  }

  const handleOK = (record, data) => {
    const titleCourse = record.status ? '您确定要禁用该用户吗? 禁用后该用户不能在后台登陆!' : '您确定要启用该用户吗? 启用后该用户将允许在后台登陆!';
    Modal.confirm({
      title: titleCourse,
      okText: '确认',
      cancelText: '取消',
      onOk () {
        publishNote(record.noteId, record.status ? 'off' : 'on').then(res => {
          message.success('操作成功');
          actionRef.current.reload()
        })
      },
    });
  }
  const actions = () => [
    <Button key='add' type="primary" icon={<PlusOutlined />} onClick={() => gotoDetail()}>新增</Button>,
  ]
  const columns = [
    {
      title: '账号',
      key: 'zz',
      dataIndex: 'zz',
    },
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
      search: false,
    },
    {
      title: '邮箱',
      dataIndex: 'a',
      key: 'a',
      search: false,
    },
    {
      title: '角色',
      dataIndex: 'weight',
      key: 'weight',
      valueType: 'select',
      render: (t, record) => record.noteType === 'peseng' ? '农户' : '农机手',
      valueEnum: {
        'peseng': { text: '农户', },
        'peseng': { text: '农机手', },
      }
    },
    {
      title: '状态',
      dataIndex: 'status',
      // initialValue: 'all',
      key: 'status',
      valueEnum: {
        0: { text: '已启用', status: 'Success' },
        1: { text: '已禁用', status: 'Error' },
      }
    },

    {
      title: (
        <>
          创建时间
          <Tooltip placement="top">
            <QuestionCircleOutlined style={{ marginLeft: 4 }} />
          </Tooltip>
        </>
      ),
      hideInTable: true,
      key: 'createdAt',
      dataIndex: 'createdAt',
      valueType: 'date',
      // render: (t) => formatterTime(t),
      sorter: (a, b) => a.createdAt - b.createdAt,
    },
    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      ellipsis: true,
      width: 200,
      render: (_, record) => [
        <Button type="link" key={1} onClick={() => handleOK(record)}>{record.status === 0 ? '启用' : '禁用'}</Button>,
        <Link key={2} to={`Administrator/AdminEdit`}>编辑</Link>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record)}
          okText="确定"
          cancelText="取消"
        >
          <a href="#"  >删除</a>
        </Popconfirm>,
      ]
    },
  ]




  return (
    <PageHeaderWrapper>
      <ProTable
        dataSource={dataSource}
        columns={columns}
        // request={getNoteList} 请求
        // rowKey="noteId"
        options={false}
        toolBarRender={actions}
        actionRef={actionRef}
      />
    </PageHeaderWrapper>
  )
}
